@@ -1,7 +1,6 @@
 package Eludia::Auth::NTLM;
 
 use Apache::AuthenNTLM;
-use Apache::Request;
 
 use Data::Dumper;
 
@@ -11,8 +10,6 @@ sub handler ($$) {
 
 	my ($self, $r) = @_;
 	
-	our $apr = undef;
-	
 	if ($r -> method eq 'POST') {
 
 		if ($r -> header_in ('Content-Length') == 0) {
@@ -30,9 +27,11 @@ sub handler ($$) {
 
 	}
 
-	our $apr = Apache::Request -> new ($r);
+	my %arg = $r -> args;
+	
+	return OK if $r -> uri =~ m{favicon\.ico$};
 
-	return OK if $apr -> param ('sid');
+	return OK if $arg {sid};
 
 	my $code = Apache::AuthenNTLM::handler ($self, $r);
 	
