@@ -1009,17 +1009,17 @@ sub do_unkill_DEFAULT {
 
 ################################################################################
 
-sub validate_kill_DEFAULT {
-	get_ids ($_REQUEST {type}) > 0 or return '     ';
-	return undef;
-}
+#sub validate_kill_DEFAULT {
+#	get_ids ($_REQUEST {type}) > 0 or return '     ';
+#	return undef;
+#}
 
 ################################################################################
 
-sub validate_unkill_DEFAULT {
-	get_ids ($_REQUEST {type}) > 0 or return '     ';
-	return undef;
-}
+#sub validate_unkill_DEFAULT {
+#	get_ids ($_REQUEST {type}) > 0 or return '     ';
+#	return undef;
+#}
 
 ################################################################################
 
@@ -1201,9 +1201,11 @@ sub call_for_role {
 
 sub __log_profilinig {
 
-	printf STDERR "Profiling [$$] %20.10f ms %s\n", 1000 * (time - $_[0]), $_[1] if ($preconf -> {core_debug_profiling} > 0);
+	my $now = time ();
+
+	printf STDERR "Profiling [$$] %20.10f ms %s\n", 1000 * ($now - $_[0]), $_[1] if ($preconf -> {core_debug_profiling} > 0);
 	
-	return time ();
+	return $now;
 
 }
 
@@ -1214,10 +1216,15 @@ sub select_subset { return {} }
 ################################################################################
 
 sub get_user {
+
 	return if $_REQUEST {type} eq '_static_files';
 
+	my $time = time;
+	
 	sql_do_refresh_sessions ();
 
+	$time = __log_profilinig ($time, ' <refresh_sessions>');
+
 	my $user = undef;
 
 	if ($_REQUEST {__login}) {
@@ -1271,19 +1278,6 @@ sub get_user {
 		$_REQUEST {sid} = $local_sid;
 		
 	}
-	
-	my $session = sql_select_hash ($conf->{systables}->{sessions}, $_REQUEST {sid});
-
-	if ($session -> {ip}) {	
-		$session -> {ip}    eq $ENV {REMOTE_ADDR}          or return undef;
-		$session -> {ip_fw} eq $ENV {HTTP_X_FORWARDED_FOR} or return undef;	
-	}	else {
-		sql_do (
-			"UPDATE $conf->{systables}->{sessions} SET ip = ?, ip_fw = ? WHERE id = ?",
-			$ENV {REMOTE_ADDR},
-			$ENV {HTTP_X_FORWARDED_FOR}, $_REQUEST {sid},
-		);
-	}
 
 	$user ||= sql_select_hash (<<EOS, $_REQUEST {sid});
 		SELECT
@@ -1291,6 +1285,8 @@ sub get_user {
 			, $conf->{systables}->{roles}.name AS role
 			, $conf->{systables}->{roles}.label AS role_label
 			, $conf->{systables}->{sessions}.id_role AS session_role
+			, $conf->{systables}->{sessions}.ip
+			, $conf->{systables}->{sessions}.id_role AS session_id_role
 		FROM
 			$conf->{systables}->{sessions}
 			, $conf->{systables}->{users}
@@ -1302,7 +1298,25 @@ sub get_user {
 			AND $conf->{systables}->{users}.fake <> -1
 EOS
 
-	if ($user && $user -> {id}) {
+	my $session = {
+		id      => $_REQUEST {sid},
+		ip      => $user -> {ip},
+		id_role => $user -> {session_id_role},
+	};
+	
+	if ($session -> {ip}) {	
+		$session -> {ip}    eq $ENV {REMOTE_ADDR}          or return undef;
+		$session -> {ip_fw} eq $ENV {HTTP_X_FORWARDED_FOR} or return undef;	
+	}	
+	elsif ($user && $user -> {id}) {
+		sql_do (
+			"UPDATE $conf->{systables}->{sessions} SET ip = ?, ip_fw = ? WHERE id = ?",
+			$ENV {REMOTE_ADDR},
+			$ENV {HTTP_X_FORWARDED_FOR}, $_REQUEST {sid},
+		);
+	}
+	
+	if ($user && $user -> {id} && $session -> {id_role}) {
 		$user -> {session_role_name} = sql_select_scalar ("SELECT name FROM $conf->{systables}->{sessions}, $conf->{systables}->{roles} WHERE $conf->{systables}->{sessions}.id_role = $conf->{systables}->{roles}.id AND $conf->{systables}->{sessions}.id = ?", $_REQUEST {sid});
 	}
 
@@ -1793,9 +1807,6 @@ sub select__info {
 		
 	require Config;
 	
-	my $skin = $_SKIN;
-	$skin =~ s{\:\:}{\/}g;
-
 	return [
 	
 		{
@@ -1820,6 +1831,12 @@ sub select__info {
 			label => $SQL_VERSION -> {string},
 		},
 
+		{
+			id    => 'DB interface',
+			label => 'DBI ' . $DBI::VERSION,
+			path  => $INC {'DBI.pm'},
+		},
+
 		{
 			id    => 'DB driver',
 			label => 'DBD::' . $db -> {Driver} -> {Name} . ' ' . ${'DBD::' . $db -> {Driver} -> {Name} . '::VERSION'},
@@ -1843,19 +1860,6 @@ sub select__info {
 			path  => join ',', @$PACKAGE_ROOT,
 		},
 
-		{			
-			id    => 'Skin',
-			label => $_SKIN,
-			path  => $INC {$skin . '.pm'},
-		},		
-
-		{			
-			id    => 'JSON module',
-			label => ref ($_JSON) eq 'JSON' ? ('JSON' . ' ' . $JSON::VERSION . ' (backend: ' . JSON->backend . ')', path => $INC {'JSON.pm'})
-				:
-				ref ($_JSON) eq 'JSON::XS' ? ('JSON::XS' . ' ' . $JSON::XS::VERSION, path => $INC {'JSON/XS.pm'})
-				: 'none',
-		},		
 	]	
 
 }
