@@ -4,25 +4,24 @@ use 5.005;
 
 require Exporter;
 
-our $VERSION = '6.06.30';
-
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 use DBI::Const::GetInfoType;
 
 use Storable    ('freeze', 'dclone');
 use Digest::MD5 'md5_base64';
+use Time::HiRes 'time';
 
 no strict;
 no warnings;
 
 ################################################################################
 
-sub is_implemented {
+sub __log_profilinig {
 
-	my ($driver_name) = @_;
+	printf STDERR "Profiling [$$] %20.10f ms %s\n", 1000 * (time - $_[0]), $_[1];
 	
-	return $driver_name eq 'MySQL' || $driver_name eq 'Oracle' || $driver_name eq 'SQLite';
+	return time ();
 
 }
 
@@ -43,10 +42,9 @@ sub new {
 	my ($package_name, $db, @options) = @_;
 	
 	my $driver_name = $db -> get_info ($GetInfoType {SQL_DBMS_NAME});
-#	my $driver_name = $db -> {Driver} -> {Name};
-	
-	is_implemented ($driver_name) or die ("DBIx::ModelUpdate error: $driver_name driver is not supported");
 	
+	$driver_name =~ s{\s}{}gsm;
+		
 	$package_name .= "::$driver_name";
 
 	eval "require $package_name";
@@ -67,10 +65,14 @@ sub new {
 	}
 
 	if ($driver_name eq 'Oracle') {
-  		$self -> {characterset} = $self -> sql_select_scalar('SELECT VALUE FROM V$NLS_PARAMETERS WHERE PARAMETER = '."'NLS_CHARACTERSET'");
+  		$self -> {characterset} = $self -> sql_select_scalar ('SELECT VALUE FROM V$NLS_PARAMETERS WHERE PARAMETER = ?', 'NLS_CHARACTERSET');
+  		$self -> {schema} ||= uc $db -> {Username};
+  		$self -> {__voc_replacements} = "$self->{quote}$self->{__voc_replacements}$self->{quote}" if $self -> {__voc_replacements} =~ /^_/;
 	}
+	
+	$self -> {schema} ||= '';
 
-	return $self;	
+	return $self;
 
 }
 
@@ -84,15 +86,16 @@ sub checksum {
 
 sub assert {
 
-#warn Dumper (\@_);
+my $time = time;
 
 	my ($self, %params) = @_;
 	
 	$Storable::canonical = 1;
 	
 	my $checksum = '';
-	my $_db_model_checksums = $self -> {_db_model_checksums} ? $self -> {_db_model_checksums} 
-		: $self -> {driver_name} eq 'Oracle' ? '"_db_model_checksums"' 
+	my $_db_model_checksums = 
+		$self -> {_db_model_checksums}     ? $self -> {_db_model_checksums} : 
+		$self -> {driver_name} eq 'Oracle' ? '"_db_model_checksums"' 
 		: '_db_model_checksums';
 
 	unless ($params {no_checksums}) {
@@ -100,40 +103,44 @@ sub assert {
 		$checksum = checksum (\%params);
 
 		return if exists $self -> {checksums} -> {$checksum};
+				
+		eval {
+		
+			my $st = $self -> {db} -> prepare ("SELECT COUNT(*) FROM $_db_model_checksums WHERE checksum = ?");
+			$st -> execute ($checksum);
+			($self -> {checksums} -> {$checksum}) = $st -> fetchrow_array;
+			$st -> finish;
 
+my $time = __log_profilinig ($time, '   checksum selected');
+		
+		};
+		
+		return if $self -> {checksums} -> {$checksum};
+		
+		if ($@) {
+		
+			my $index_name = $_db_model_checksums;
+			$index_name =~ s{(\w+)}{$1_pk};
+		
+			$self -> do ("CREATE TABLE $_db_model_checksums (checksum CHAR(22))");
+			$self -> do ("CREATE INDEX $index_name ON $_db_model_checksums (checksum)");
+		
+my $time = __log_profilinig ($time, '   checksum table created');
+
+		}
 
 	}	
 
-	my @tables = $self -> {db} -> tables;
-
-	my $existing_tables =  { 
-		map { 
-			$_ => {} 
-		} 
-		map {
-			$self -> unquote_table_name ($_)
-		}
-		@tables
-	};
-
-	unless ($params {no_checksums}) {
-
-		unless (exists $existing_tables -> {$_db_model_checksums}) {
-			$self -> do ("CREATE TABLE $_db_model_checksums (checksum CHAR(22))");
-			$self -> do ("CREATE INDEX ${_db_model_checksums}_pk ON $_db_model_checksums (checksum)");
-		} else {
-
-			my $st = $self -> {db} -> prepare ("SELECT COUNT(*) FROM $_db_model_checksums WHERE checksum = ?");
-			$st -> execute ($checksum);
-			my ($cnt) = $st -> fetchrow_array;
-			$st -> finish;
-
-			return if $cnt;
-
-		}
-			
+	my $existing_tables = {};	
+	
+	foreach ($self -> {db} -> tables ('', $self -> {schema}, '%', "'TABLE'")) {
+	
+		$existing_tables -> {$self -> unquote_table_name ($_)} = {};
+	
 	}
 
+my $time = __log_profilinig ($time, '   got existing_tables');
+
 	&{$self -> {before_assert}} (@_) if ref $self -> {before_assert} eq CODE;		
 	
 	my $needed_tables = $params {tables};
@@ -171,14 +178,16 @@ sub assert {
 	
 	};
 
+my $time = __log_profilinig ($time, '   needed_tables filtered');
 		
 	foreach my $name (keys %$needed_tables) {
 		exists $existing_tables -> {$name} or next;
 		$existing_tables -> {$name} -> {columns} = $self -> get_columns ($name); 
 		$existing_tables -> {$name} -> {keys}    = $self -> get_keys    ($name, $params {core_voc_replacement_use}); 
 	} 
+
+my $time = __log_profilinig ($time, '   got keys & columns');
 	
-#	while (my ($name, $definition) = each %$needed_tables) {
 	foreach my $name (keys %$needed_tables) {
 	
 		my $definition = $needed_tables -> {$name};
@@ -199,7 +208,9 @@ sub assert {
 				
 					my $existing_column = $existing_columns -> {$c_name};										
 					$self -> update_column ($name, $c_name, $existing_column, $c_definition,,$params {core_voc_replacement_use});
-								
+
+my $time = __log_profilinig ($time, "    $name.$c_name updated");
+
 				}
 				else {
 				
@@ -211,21 +222,24 @@ sub assert {
 
 			$self -> add_columns ($name, $new_columns,,$params {core_voc_replacement_use}) if keys %$new_columns;
 
-#			while (my ($k_name, $k_definition) = each %{$definition -> {keys}}) {
+my $time = __log_profilinig ($time, "    columns added");
+
 			foreach my $k_name (keys %{$definition -> {keys}}) {
 			
 				my $k_definition = $definition -> {keys} -> {$k_name};
 			
 				$k_definition =~ s{\s+}{}g;
 			
-
 				if (
 					$existing_tables -> {$name} 
 					&& $existing_tables -> {$name} -> {keys} -> {$k_name}
 				) {
 				
-					if ($existing_tables -> {$name} -> {keys} -> {$k_name} -> {columns} ne $k_definition) {
+					$existing_tables -> {$name} -> {keys} -> {$k_name} =~ s{\s+}{}g; 					
+
+					if ($existing_tables -> {$name} -> {keys} -> {$k_name} ne $k_definition) {
 						$self -> drop_index ($name, $k_name, $params {core_voc_replacement_use});
+my $time = __log_profilinig ($time, "    key $name.$k_name dropped");
 					}
 					else {
 						next;
@@ -235,6 +249,7 @@ sub assert {
 				
 				$self -> create_index ($name, $k_name, $k_definition, $definition, $params {core_voc_replacement_use});
 
+my $time = __log_profilinig ($time, "    key $name.$k_name created");
 			};
 
 		}
@@ -257,15 +272,17 @@ sub assert {
 
 		map { $self -> insert_or_update ($name, $_, $definition) } @{$definition -> {data}} if $definition -> {data};
 		
-		$self -> do ("INSERT INTO $_db_model_checksums (checksum) VALUES ('$checksum')") unless $params {no_checksums};
-		
+		unless ($params {no_checksums}) {
+			$self -> do ("INSERT INTO $_db_model_checksums (checksum) VALUES ('$checksum')") unless $params {no_checksums};
+		}
+
 	}
-			
+
 	unless ($params {no_checksums}) {
 		$self -> do ("INSERT INTO $_db_model_checksums (checksum) VALUES ('$checksum')");
 		$self -> {checksums} -> {$checksum} = 1;	
 	}
-				
+
 }
 
 ################################################################################
